@@ -33,7 +33,7 @@ from .utilles import (
     argument_signature,
     dispatcher_mixin_handler,
     group_dict,
-    run_always_await_safely,
+    run_always_await,
 )
 
 
@@ -102,7 +102,7 @@ class Broadcast:
         event: Dispatchable,
         addition_dispatchers: Optional[List["T_Dispatcher"]] = None,
     ):
-        grouped: Dict[int, List[Listener]] = group_dict(listener_generator, lambda x: x.priority)
+        grouped: Dict[int, List[Listener]] = group_dict(listener_generator, lambda x: x.priorities.get(event.__class__) or x.priority)
         event_dispatcher_mixin = dispatcher_mixin_handler(event.Dispatcher)
         if addition_dispatchers:
             event_dispatcher_mixin = event_dispatcher_mixin + addition_dispatchers
@@ -157,7 +157,7 @@ class Broadcast:
             for dispatcher in dispatchers:
                 i = getattr(dispatcher, "beforeExecution", None)
                 if i:
-                    await run_always_await_safely(i, dii)  # type: ignore
+                    await run_always_await(i, dii)  # type: ignore
 
             if is_exectarget:
                 for name, annotation, default in argument_signature(target_callable):
@@ -183,9 +183,9 @@ class Broadcast:
             for dispatcher in dispatchers:
                 i = getattr(dispatcher, "afterDispatch", None)
                 if i:
-                    await run_always_await_safely(i, dii, None, None)
+                    await run_always_await(i, dii, None, None)
 
-            result = await run_always_await_safely(target_callable, **parameter_compile_result)
+            result = await run_always_await(target_callable, **parameter_compile_result)
         except (ExecutionStop, PropagationCancelled):
             raise
         except RequirementCrashed:
@@ -204,7 +204,7 @@ class Broadcast:
             for dispatcher in dispatchers:
                 i = getattr(dispatcher, "afterExecution", None)
                 if i:
-                    await run_always_await_safely(i, dii, exception, tb)  # type: ignore
+                    await run_always_await(i, dii, exception, tb)  # type: ignore
 
             dii.ctx.reset(dii_token)
 
@@ -236,7 +236,7 @@ class Broadcast:
             for dispatcher in dispatchers:
                 i = getattr(dispatcher, "beforeExecution", None)
                 if i:
-                    await run_always_await_safely(i, dii, exception, tb)  # type: ignore
+                    await run_always_await(i, dii, exception, tb)  # type: ignore
             yield dii
         except RequirementCrashed:
             traceback.print_exc()
@@ -254,7 +254,7 @@ class Broadcast:
             for dispatcher in dispatchers:
                 i = getattr(dispatcher, "afterExecution", None)
                 if i:
-                    await run_always_await_safely(i, dii, exception, tb)  # type: ignore
+                    await run_always_await(i, dii, exception, tb)  # type: ignore
 
             dii.ctx.reset(dii_token)
 
