@@ -29,17 +29,11 @@ if TYPE_CHECKING:
     from graia.broadcast.typing import T_Dispatcher
 
 
-async def run_always_await(any_callable: Union[Awaitable, Callable]):
-    if inspect.isawaitable(any_callable):
-        return await any_callable
-    else:
-        return any_callable
-
-
-async def run_always_await_safely(callable, *args, **kwargs):
-    if iscoroutinefunction(callable):
-        return await callable(*args, **kwargs)
-    return callable(*args, **kwargs)
+async def run_always_await(callable, *args, **kwargs):
+    obj = callable(*args, **kwargs)
+    while inspect.isawaitable(obj):
+        obj = await obj
+    return obj
 
 
 T = TypeVar("T")
@@ -86,8 +80,9 @@ class DebugList(UserList):
         print(i, item)
         return super().insert(i, item)
 
+K = TypeVar("K")
 
-def group_dict(iterable: Iterable, key_callable: Callable[[Any], Any]):
+def group_dict(iterable: Iterable[T], key_callable: Callable[[T], K]) -> Dict[K, List[T]]:
     temp = {}
     for i in iterable:
         k = key_callable(i)
